@@ -1,4 +1,4 @@
-use clap::crate_version;
+use clap::{arg_enum, crate_version, value_t};
 
 use gio::prelude::*;
 use gio::{Cancellable, FileCreateFlags, InputStream, OutputStream};
@@ -18,15 +18,11 @@ mod windows_imports {
 #[cfg(windows)]
 use self::windows_imports::*;
 
-use cssparser::{_cssparser_internal_to_lowercase, match_ignore_ascii_case};
-
 use librsvg::rsvg_convert_only::{
     AspectRatio, CssLength, Dpi, Horizontal, LegacySize, Length, Normalize, NormalizeParams, Parse,
-    PathOrUrl, Rect, Signed, ULength, Unsigned, Validate, Vertical, ViewBox,
+    PathOrUrl, Rect, ULength, Validate, Vertical, ViewBox,
 };
 use librsvg::{AcceptLanguage, CairoRenderer, Color, Language, LengthUnit, Loader, RenderingError};
-
-use std::ffi::OsString;
 use std::ops::Deref;
 use std::path::PathBuf;
 
@@ -47,7 +43,7 @@ impl From<cairo::Error> for Error {
                  Librsvg currently cannot render to images bigger than that.\n\
                  Please specify a smaller size.",
             )),
-            e => Self(format!("{e}")),
+            e => Self(format!("{}", e)),
         }
     }
 }
@@ -56,7 +52,7 @@ macro_rules! impl_error_from {
     ($err:ty) => {
         impl From<$err> for Error {
             fn from(e: $err) -> Self {
-                Self(format!("{e}"))
+                Self(format!("{}", e))
             }
         }
     };
@@ -215,7 +211,6 @@ impl ResizeStrategy {
     }
 }
 
-#[allow(dead_code)]
 enum Surface {
     Png(cairo::ImageSurface, OutputStream),
     #[cfg(system_deps_have_cairo_pdf)]
@@ -395,7 +390,7 @@ mod metadata {
         match env::var("SOURCE_DATE_EPOCH") {
             Ok(epoch) => match i64::from_str(&epoch) {
                 Ok(seconds) => {
-                    let datetime = Utc.timestamp_opt(seconds, 0).unwrap();
+                    let datetime = Utc.timestamp(seconds, 0);
                     Ok(Some(datetime.to_rfc3339()))
                 }
                 Err(e) => Err(error!("Environment variable $SOURCE_DATE_EPOCH: {}", e)),
@@ -473,19 +468,20 @@ impl std::fmt::Display for Output {
     }
 }
 
-// Keep this enum in sync with supported_formats in parse_args()
-#[derive(Clone, Copy, Debug)]
-enum Format {
-    Png,
-    Pdf,
-    Ps,
-    Eps,
-    Svg,
+arg_enum! {
+    // Keep this enum in sync with supported_formats in parse_args()
+    #[derive(Clone, Copy, Debug)]
+    enum Format {
+        Png,
+        Pdf,
+        Ps,
+        Eps,
+        Svg,
+    }
 }
 
 struct Converter {
-    pub dpi_x: Resolution,
-    pub dpi_y: Resolution,
+    pub dpi: (f64, f64),
     pub zoom: Scale,
     pub width: Option<ULength<Horizontal>>,
     pub height: Option<ULength<Vertical>>,
@@ -559,7 +555,7 @@ impl Converter {
             }
 
             let renderer = CairoRenderer::new(&handle)
-                .with_dpi(self.dpi_x.0, self.dpi_y.0)
+                .with_dpi(self.dpi.0, self.dpi.1)
                 .with_language(&self.language)
                 .test_mode(self.testing);
 
@@ -567,7 +563,7 @@ impl Converter {
 
             let natural_size = Size::new(geometry.width, geometry.height);
 
-            let params = NormalizeParams::from_dpi(Dpi::new(self.dpi_x.0, self.dpi_y.0));
+            let params = NormalizeParams::from_dpi(Dpi::new(self.dpi.0, self.dpi.1));
 
             // Convert natural size and requested size to pixels or points, depending on the target format,
             let (natural_size, requested_width, requested_height, page_size) = match self.format {
@@ -772,304 +768,258 @@ fn natural_geometry(
 
 fn parse_args() -> Result<Converter, Error> {
     let supported_formats = vec![
-        "png",
+        "Png",
         #[cfg(system_deps_have_cairo_pdf)]
-        "pdf",
+        "Pdf",
         #[cfg(system_deps_have_cairo_ps)]
-        "ps",
+        "Ps",
         #[cfg(system_deps_have_cairo_ps)]
-        "eps",
+        "Eps",
         #[cfg(system_deps_have_cairo_svg)]
-        "svg",
+        "Svg",
     ];
 
-    let app = clap::Command::new("rsvg-convert")
+    let app = clap::App::new("rsvg-convert")
         .version(concat!("version ", crate_version!()))
         .about("Convert SVG files to other image formats")
-        .disable_version_flag(true)
-        .disable_help_flag(true)
+        .help_short("?")
+        .version_short("v")
         .arg(
-            clap::Arg::new("help")
-                .short('?')
-                .long("help")
-                .help("Display the help")
-                .action(clap::ArgAction::Help)
-        )
-        .arg(
-            clap::Arg::new("version")
-                .short('v')
-                .long("version")
-                .help("Display the version information")
-                .action(clap::ArgAction::Version)
-        )
-        .arg(
-            clap::Arg::new("res_x")
-                .short('d')
+            clap::Arg::with_name("res_x")
+                .short("d")
                 .long("dpi-x")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("number")
                 .default_value("96")
-                .value_parser(parse_resolution)
-                .help("Pixels per inch")
-                .action(clap::ArgAction::Set),
+                .validator(is_valid_resolution)
+                .help("Pixels per inch"),
         )
         .arg(
-            clap::Arg::new("res_y")
-                .short('p')
+            clap::Arg::with_name("res_y")
+                .short("p")
                 .long("dpi-y")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("number")
                 .default_value("96")
-                .value_parser(parse_resolution)
-                .help("Pixels per inch")
-                .action(clap::ArgAction::Set),
+                .validator(is_valid_resolution)
+                .help("Pixels per inch"),
         )
         .arg(
-            clap::Arg::new("zoom_x")
-                .short('x')
+            clap::Arg::with_name("zoom_x")
+                .short("x")
                 .long("x-zoom")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("number")
                 .conflicts_with("zoom")
-                .value_parser(parse_zoom_factor)
-                .help("Horizontal zoom factor")
-                .action(clap::ArgAction::Set),
+                .validator(is_valid_zoom_factor)
+                .help("Horizontal zoom factor"),
         )
         .arg(
-            clap::Arg::new("zoom_y")
-                .short('y')
+            clap::Arg::with_name("zoom_y")
+                .short("y")
                 .long("y-zoom")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("number")
                 .conflicts_with("zoom")
-                .value_parser(parse_zoom_factor)
-                .help("Vertical zoom factor")
-                .action(clap::ArgAction::Set),
+                .validator(is_valid_zoom_factor)
+                .help("Vertical zoom factor"),
         )
         .arg(
-            clap::Arg::new("zoom")
-                .short('z')
+            clap::Arg::with_name("zoom")
+                .short("z")
                 .long("zoom")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("number")
-                .value_parser(parse_zoom_factor)
-                .help("Zoom factor")
-                .action(clap::ArgAction::Set),
+                .validator(is_valid_zoom_factor)
+                .help("Zoom factor"),
         )
         .arg(
-            clap::Arg::new("size_x")
-                .short('w')
+            clap::Arg::with_name("size_x")
+                .short("w")
                 .long("width")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("length")
-                .value_parser(parse_length::<Horizontal, Unsigned>)
-                .help("Width [defaults to the width of the SVG]")
-                .action(clap::ArgAction::Set),
+                .help("Width [defaults to the width of the SVG]"),
         )
         .arg(
-            clap::Arg::new("size_y")
-                .short('h')
+            clap::Arg::with_name("size_y")
+                .short("h")
                 .long("height")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("length")
-                .value_parser(parse_length::<Vertical, Unsigned>)
-                .help("Height [defaults to the height of the SVG]")
-                .action(clap::ArgAction::Set),
+                .help("Height [defaults to the height of the SVG]"),
         )
         .arg(
-            clap::Arg::new("top")
+            clap::Arg::with_name("top")
                 .long("top")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("length")
-                .value_parser(parse_length::<Vertical, Signed>)
-                .help("Distance between top edge of page and the image [defaults to 0]")
-                .action(clap::ArgAction::Set),
+                .help("Distance between top edge of page and the image [defaults to 0]"),
         )
         .arg(
-            clap::Arg::new("left")
+            clap::Arg::with_name("left")
                 .long("left")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("length")
-                .value_parser(parse_length::<Horizontal, Signed>)
-                .help("Distance between left edge of page and the image [defaults to 0]")
-                .action(clap::ArgAction::Set),
+                .help("Distance between left edge of page and the image [defaults to 0]"),
         )
         .arg(
-            clap::Arg::new("page_width")
+            clap::Arg::with_name("page_width")
                 .long("page-width")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("length")
-                .value_parser(parse_length::<Horizontal, Unsigned>)
-                .help("Width of output media [defaults to the width of the SVG]")
-                .action(clap::ArgAction::Set),
+                .help("Width of output media [defaults to the width of the SVG]"),
         )
         .arg(
-            clap::Arg::new("page_height")
+            clap::Arg::with_name("page_height")
                 .long("page-height")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("length")
-                .value_parser(parse_length::<Vertical, Unsigned>)
-                .help("Height of output media [defaults to the height of the SVG]")
-                .action(clap::ArgAction::Set),
+                .help("Height of output media [defaults to the height of the SVG]"),
         )
         .arg(
-            clap::Arg::new("format")
-                .short('f')
+            clap::Arg::with_name("format")
+                .short("f")
                 .long("format")
-                .num_args(1)
-                .value_parser(clap::builder::PossibleValuesParser::new(supported_formats.as_slice()))
-                .ignore_case(true)
+                .takes_value(true)
+                .possible_values(supported_formats.as_slice())
+                .case_insensitive(true)
                 .default_value("png")
-                .help("Output format")
-                .action(clap::ArgAction::Set),
+                .help("Output format"),
         )
         .arg(
-            clap::Arg::new("output")
-                .short('o')
+            clap::Arg::with_name("output")
+                .short("o")
                 .long("output")
-                .num_args(1)
-                .value_parser(clap::value_parser!(PathBuf))
-                .help("Output filename [defaults to stdout]")
-                .action(clap::ArgAction::Set),
+                .empty_values(false)
+                .help("Output filename [defaults to stdout]"),
         )
         .arg(
-            clap::Arg::new("export_id")
-                .short('i')
+            clap::Arg::with_name("export_id")
+                .short("i")
                 .long("export-id")
-                .value_parser(clap::builder::NonEmptyStringValueParser::new())
+                .empty_values(false)
                 .value_name("object id")
-                .help("SVG id of object to export [default is to export all objects]")
-                .action(clap::ArgAction::Set),
+                .help("SVG id of object to export [default is to export all objects]"),
         )
         .arg(
-            clap::Arg::new("accept-language")
-                .short('l')
+            clap::Arg::with_name("accept-language")
+                .short("l")
                 .long("accept-language")
-                .value_parser(clap::builder::NonEmptyStringValueParser::new())
+                .empty_values(false)
                 .value_name("languages")
-                .help("Languages to accept, for example \"es-MX,de,en\" [default uses language from the environment]")
-                .action(clap::ArgAction::Set),
+                .help("Languages to accept, for example \"es-MX,de,en\" [default uses language from the environment]"),
         )
         .arg(
-            clap::Arg::new("keep_aspect")
-                .short('a')
+            clap::Arg::with_name("keep_aspect")
+                .short("a")
                 .long("keep-aspect-ratio")
-                .help("Preserve the aspect ratio")
-                .action(clap::ArgAction::SetTrue),
+                .help("Preserve the aspect ratio"),
         )
         .arg(
-            clap::Arg::new("background")
-                .short('b')
+            clap::Arg::with_name("background")
+                .short("b")
                 .long("background-color")
-                .num_args(1)
+                .takes_value(true)
                 .value_name("color")
-                .value_parser(clap::builder::NonEmptyStringValueParser::new())
-                .default_value("none")
-                .help("Set the background color using a CSS color spec")
-                .action(clap::ArgAction::Set),
+                .help("Set the background color using a CSS color spec"),
         )
         .arg(
-            clap::Arg::new("stylesheet")
-                .short('s')
+            clap::Arg::with_name("stylesheet")
+                .short("s")
                 .long("stylesheet")
-            .num_args(1)
-                .value_parser(clap::value_parser!(PathBuf))
+                .empty_values(false)
                 .value_name("filename.css")
-                .help("Filename of CSS stylesheet to apply")
-                .action(clap::ArgAction::Set),
+                .help("Filename of CSS stylesheet to apply"),
         )
         .arg(
-            clap::Arg::new("unlimited")
-                .short('u')
+            clap::Arg::with_name("unlimited")
+                .short("u")
                 .long("unlimited")
-                .help("Allow huge SVG files")
-                .action(clap::ArgAction::SetTrue),
+                .help("Allow huge SVG files"),
         )
         .arg(
-            clap::Arg::new("keep_image_data")
+            clap::Arg::with_name("keep_image_data")
                 .long("keep-image-data")
-                .help("Keep image data")
-                .conflicts_with("no_keep_image_data")
-                .action(clap::ArgAction::SetTrue),
+                .help("Keep image data"),
         )
         .arg(
-            clap::Arg::new("no_keep_image_data")
+            clap::Arg::with_name("no_keep_image_data")
                 .long("no-keep-image-data")
-                .help("Do not keep image data")
-                .conflicts_with("keep_image_data")
-                .action(clap::ArgAction::SetTrue),
+                .help("Do not keep image data"),
         )
         .arg(
-            clap::Arg::new("testing")
+            clap::Arg::with_name("testing")
                 .long("testing")
                 .help("Render images for librsvg's test suite")
-                .hide(true)
-                .action(clap::ArgAction::SetTrue),
+                .hidden(true),
         )
         .arg(
-            clap::Arg::new("FILE")
-                .value_parser(clap::value_parser!(OsString))
+            clap::Arg::with_name("FILE")
                 .help("The input file(s) to convert")
-                .num_args(1..)
-                .action(clap::ArgAction::Append),
+                .multiple(true),
         );
 
     let matches = app.get_matches();
 
-    let format_str: &String = matches
-        .get_one("format")
-        .expect("already provided default_value");
-
-    let format = match_ignore_ascii_case! {
-        format_str,
-        "png" => Format::Png,
-        "pdf" => Format::Pdf,
-        "ps" => Format::Ps,
-        "eps" => Format::Eps,
-        "svg" => Format::Svg,
-        _ => unreachable!("clap should already have the list of possible values"),
-    };
+    let format = value_t!(matches, "format", Format)?;
 
     let keep_image_data = match format {
-        Format::Ps | Format::Eps | Format::Pdf => !matches.get_flag("no_keep_image_data"),
-        _ => matches.get_flag("keep_image_data"),
+        Format::Ps | Format::Eps | Format::Pdf => !matches.is_present("no_keep_image_data"),
+        _ => matches.is_present("keep_image_data"),
     };
 
-    let language = match matches.get_one::<String>("accept-language") {
-        None => Language::FromEnvironment,
-        Some(s) => AcceptLanguage::parse(s)
-            .map(Language::AcceptLanguage)
-            .map_err(|e| {
-                let desc = format!("{}", e);
-                clap::Error::raw(clap::error::ErrorKind::InvalidValue, desc)
-            })?,
-    };
+    let language = value_t!(matches, "accept-language", String)
+        .or_none()
+        .and_then(|lang_str| match lang_str {
+            None => Ok(Language::FromEnvironment),
+            Some(s) => AcceptLanguage::parse(&s)
+                .map(Language::AcceptLanguage)
+                .map_err(|e| {
+                    let desc = format!("{}", e);
+                    clap::Error::with_description(&desc, clap::ErrorKind::InvalidValue)
+                }),
+        });
 
-    let background_str: &String = matches
-        .get_one("background")
-        .expect("already provided default_value");
-    let background_color: Option<Color> = parse_background_color(background_str)
-        .map_err(|e| clap::Error::raw(clap::error::ErrorKind::InvalidValue, e))?;
+    let background_color = value_t!(matches, "background", String).and_then(parse_color_string);
 
     // librsvg expects ids starting with '#', so it can lookup ids in externs like "subfile.svg#subid".
     // For the user's convenience, we prepend '#' automatically; we only support specifying ids from
     // the toplevel, and don't expect users to lookup things in externs.
-    let lookup_id = |id: &String| {
+    let lookup_id = |id: String| {
         if id.starts_with('#') {
-            id.clone()
+            id
         } else {
             format!("#{}", id)
         }
     };
 
-    let width: Option<ULength<Horizontal>> = matches.get_one("size_x").copied();
-    let height: Option<ULength<Vertical>> = matches.get_one("size_y").copied();
+    let width = value_t!(matches, "size_x", String)
+        .or_none()?
+        .map(parse_length)
+        .transpose()?;
+    let height = value_t!(matches, "size_y", String)
+        .or_none()?
+        .map(parse_length)
+        .transpose()?;
 
-    let left: Option<Length<Horizontal>> = matches.get_one("left").copied();
-    let top: Option<Length<Vertical>> = matches.get_one("top").copied();
+    let left = value_t!(matches, "left", String)
+        .or_none()?
+        .map(parse_length)
+        .transpose()?;
+    let top = value_t!(matches, "top", String)
+        .or_none()?
+        .map(parse_length)
+        .transpose()?;
 
-    let page_width: Option<ULength<Horizontal>> = matches.get_one("page_width").copied();
-    let page_height: Option<ULength<Vertical>> = matches.get_one("page_height").copied();
+    let page_width = value_t!(matches, "page_width", String)
+        .or_none()?
+        .map(parse_length)
+        .transpose()?;
+    let page_height = value_t!(matches, "page_height", String)
+        .or_none()?
+        .map(parse_length)
+        .transpose()?;
 
     let page_size = match (page_width, page_height) {
         (None, None) => None,
@@ -1081,18 +1031,11 @@ fn parse_args() -> Result<Converter, Error> {
         (Some(w), Some(h)) => Some((w, h)),
     };
 
-    let dpi_x = *matches
-        .get_one::<Resolution>("res_x")
-        .expect("already provided default_value");
-    let dpi_y = *matches
-        .get_one::<Resolution>("res_y")
-        .expect("already provided default_value");
+    let zoom = value_t!(matches, "zoom", f64).or_none()?;
+    let zoom_x = value_t!(matches, "zoom_x", f64).or_none()?;
+    let zoom_y = value_t!(matches, "zoom_y", f64).or_none()?;
 
-    let zoom: Option<ZoomFactor> = matches.get_one("zoom").copied();
-    let zoom_x: Option<ZoomFactor> = matches.get_one("zoom_x").copied();
-    let zoom_y: Option<ZoomFactor> = matches.get_one("zoom_y").copied();
-
-    let input = match matches.get_many::<std::ffi::OsString>("FILE") {
+    let input = match matches.values_of_os("FILE") {
         Some(values) => values
             .map(|f| PathOrUrl::from_os_str(f).map_err(Error))
             .map(|r| r.map(Input::Named))
@@ -1107,19 +1050,14 @@ fn parse_args() -> Result<Converter, Error> {
         ));
     }
 
-    let export_id: Option<String> = matches.get_one::<String>("export_id").map(lookup_id);
-
-    let output = match matches.get_one::<PathBuf>("output") {
-        None => Output::Stdout,
-        Some(path) => Output::Path(path.clone()),
-    };
-
     Ok(Converter {
-        dpi_x,
-        dpi_y,
+        dpi: (
+            value_t!(matches, "res_x", f64)?,
+            value_t!(matches, "res_y", f64)?,
+        ),
         zoom: Scale {
-            x: zoom.or(zoom_x).map(|factor| factor.0).unwrap_or(1.0),
-            y: zoom.or(zoom_y).map(|factor| factor.0).unwrap_or(1.0),
+            x: zoom.or(zoom_x).unwrap_or(1.0),
+            y: zoom.or(zoom_y).unwrap_or(1.0),
         },
         width,
         height,
@@ -1127,49 +1065,80 @@ fn parse_args() -> Result<Converter, Error> {
         top,
         page_size,
         format,
-        export_id,
-        keep_aspect_ratio: matches.get_flag("keep_aspect"),
-        background_color,
-        stylesheet: matches.get_one("stylesheet").cloned(),
-        unlimited: matches.get_flag("unlimited"),
+        export_id: value_t!(matches, "export_id", String)
+            .or_none()?
+            .map(lookup_id),
+        keep_aspect_ratio: matches.is_present("keep_aspect"),
+        background_color: background_color.or_none()?,
+        stylesheet: matches.value_of_os("stylesheet").map(PathBuf::from),
+        unlimited: matches.is_present("unlimited"),
         keep_image_data,
-        language,
+        language: language?,
         input,
-        output,
-        testing: matches.get_flag("testing"),
+        output: matches
+            .value_of_os("output")
+            .map(PathBuf::from)
+            .map(Output::Path)
+            .unwrap_or(Output::Stdout),
+        testing: matches.is_present("testing"),
     })
 }
 
-#[derive(Copy, Clone)]
-struct Resolution(f64);
-
-fn parse_resolution(v: &str) -> Result<Resolution, String> {
+fn is_valid_resolution(v: String) -> Result<(), String> {
     match v.parse::<f64>() {
-        Ok(res) if res > 0.0 => Ok(Resolution(res)),
+        Ok(res) if res > 0.0 => Ok(()),
         Ok(_) => Err(String::from("Invalid resolution")),
         Err(e) => Err(format!("{}", e)),
     }
 }
 
-#[derive(Copy, Clone)]
-struct ZoomFactor(f64);
-
-fn parse_zoom_factor(v: &str) -> Result<ZoomFactor, String> {
+fn is_valid_zoom_factor(v: String) -> Result<(), String> {
     match v.parse::<f64>() {
-        Ok(res) if res > 0.0 => Ok(ZoomFactor(res)),
+        Ok(res) if res > 0.0 => Ok(()),
         Ok(_) => Err(String::from("Invalid zoom factor")),
         Err(e) => Err(format!("{}", e)),
     }
 }
 
-fn parse_background_color(s: &str) -> Result<Option<Color>, String> {
-    match s {
-        "none" | "None" => Ok(None),
-        _ => <Color as Parse>::parse_str(s).map(Some).map_err(|_| {
-            format!(
+trait NotFound {
+    type Ok;
+    type Error;
+
+    fn or_none(self) -> Result<Option<Self::Ok>, Self::Error>;
+}
+
+impl<T> NotFound for Result<T, clap::Error> {
+    type Ok = T;
+    type Error = clap::Error;
+
+    /// Maps the Result to an Option, translating the ArgumentNotFound error to
+    /// Ok(None), while mapping other kinds of errors to Err(e).
+    ///
+    /// This allows to get proper error reporting for invalid values on optional
+    /// arguments.
+    fn or_none(self) -> Result<Option<T>, clap::Error> {
+        self.map_or_else(
+            |e| match e.kind {
+                clap::ErrorKind::ArgumentNotFound => Ok(None),
+                _ => Err(e),
+            },
+            |v| Ok(Some(v)),
+        )
+    }
+}
+
+fn parse_color_string<T: AsRef<str> + std::fmt::Display>(s: T) -> Result<Color, clap::Error> {
+    match s.as_ref() {
+        "none" | "None" => Err(clap::Error::with_description(
+            s.as_ref(),
+            clap::ErrorKind::ArgumentNotFound,
+        )),
+        _ => <Color as Parse>::parse_str(s.as_ref()).map_err(|_| {
+            let desc = format!(
                 "Invalid value: The argument '{}' can not be parsed as a CSS color value",
                 s
-            )
+            );
+            clap::Error::with_description(&desc, clap::ErrorKind::InvalidValue)
         }),
     }
 }
@@ -1183,21 +1152,26 @@ fn is_absolute_unit(u: LengthUnit) -> bool {
     }
 }
 
-fn parse_length<N: Normalize, V: Validate>(s: &str) -> Result<CssLength<N, V>, String> {
-    <CssLength<N, V> as Parse>::parse_str(s)
+fn parse_length<N: Normalize, V: Validate>(s: String) -> Result<CssLength<N, V>, clap::Error> {
+    <CssLength<N, V> as Parse>::parse_str(&s)
         .map_err(|_| {
-            format!(
+            let desc = format!(
                 "Invalid value: The argument '{}' can not be parsed as a length",
                 s
-            )
+            );
+            clap::Error::with_description(&desc, clap::ErrorKind::InvalidValue)
         })
         .and_then(|l| {
             if is_absolute_unit(l.unit) {
                 Ok(l)
             } else {
-                Err(format!(
+                let desc = format!(
                     "Invalid value '{}': supported units are px, in, cm, mm, pt, pc",
                     s
+                );
+                Err(clap::Error::with_description(
+                    &desc,
+                    clap::ErrorKind::InvalidValue,
                 ))
             }
         })
@@ -1216,17 +1190,23 @@ mod color_tests {
 
     #[test]
     fn valid_color_is_ok() {
-        assert!(parse_background_color("Red").is_ok());
+        assert!(parse_color_string("Red").is_ok());
     }
 
     #[test]
-    fn none_is_handled_as_transparent() {
-        assert_eq!(parse_background_color("None").unwrap(), None,);
+    fn none_is_handled_as_not_found() {
+        assert_eq!(
+            parse_color_string("None").map_err(|e| e.kind),
+            Err(clap::ErrorKind::ArgumentNotFound)
+        );
     }
 
     #[test]
     fn invalid_is_handled_as_invalid_value() {
-        assert!(parse_background_color("foo").is_err());
+        assert_eq!(
+            parse_color_string("foo").map_err(|e| e.kind),
+            Err(clap::ErrorKind::InvalidValue)
+        );
     }
 }
 
