@@ -14,6 +14,7 @@ use crate::layout::StackingContext;
 use crate::length::*;
 use crate::node::{CascadedValues, Node, NodeBorrow, NodeDraw};
 use crate::parsers::{Parse, ParseValue};
+use crate::properties::ComputedValues;
 use crate::rect::Rect;
 use crate::viewbox::*;
 use crate::xml::Attributes;
@@ -89,7 +90,12 @@ impl Draw for Switch {
                     let elt = c.borrow_element();
                     elt.get_cond(dc.user_language()) && !elt.is_in_error()
                 }) {
-                    child.draw(an, &CascadedValues::new(cascaded, &child), dc, clipping)
+                    child.draw(
+                        an,
+                        &CascadedValues::clone_with_node(cascaded, &child),
+                        dc,
+                        clipping,
+                    )
                 } else {
                     Ok(dc.empty_bbox())
                 }
@@ -98,44 +104,46 @@ impl Draw for Switch {
     }
 }
 
-/// Intrinsic dimensions of an SVG document fragment: its `width`, `height`, `viewBox` attributes.
+/// Intrinsic dimensions of an SVG document fragment: its `width/height` properties and  `viewBox` attribute.
 ///
-/// Note that either of those attributes can be omitted, so they are all `Option<T>`.
-/// For example, an element like `<svg viewBox="0 0 100 100">` will have `vbox=Some(...)`,
-/// and the other two fields set to `None`.
+/// Note that in SVG2, `width` and `height` are properties, not
+/// attributes.  If either is omitted, it defaults to `auto`. which
+/// computes to `100%`.
+///
+/// The `viewBox` attribute can also be omitted, hence an `Option`.
 #[derive(Debug, Copy, Clone, PartialEq)]
 pub struct IntrinsicDimensions {
-    /// Contents of the `width` attribute.
-    pub width: Option<ULength<Horizontal>>,
+    /// Computed value of the `width` property.
+    pub width: ULength<Horizontal>,
 
-    /// Contents of the `height` attribute.
-    pub height: Option<ULength<Vertical>>,
+    /// Computed value of the `height` property.
+    pub height: ULength<Vertical>,
 
     /// Contents of the `viewBox` attribute.
     pub vbox: Option<ViewBox>,
 }
 
+/// The `<svg>` element.
+///
+/// Note that its x/y/width/height are properties in SVG2, so they are
+/// defined as part of [the properties machinery](properties.rs).
 #[derive(Default)]
 pub struct Svg {
     preserve_aspect_ratio: AspectRatio,
-    x: Option<Length<Horizontal>>,
-    y: Option<Length<Vertical>>,
-    width: Option<LengthOrAuto<Horizontal>>,
-    height: Option<LengthOrAuto<Vertical>>,
     vbox: Option<ViewBox>,
 }
 
 impl Svg {
-    pub fn get_intrinsic_dimensions(&self) -> IntrinsicDimensions {
-        let w = self.width.map(|length_or_auto| match length_or_auto {
+    pub fn get_intrinsic_dimensions(&self, values: &ComputedValues) -> IntrinsicDimensions {
+        let w = match values.width().0 {
             LengthOrAuto::Auto => ULength::<Horizontal>::parse_str("100%").unwrap(),
             LengthOrAuto::Length(l) => l,
-        });
+        };
 
-        let h = self.height.map(|length_or_auto| match length_or_auto {
+        let h = match values.height().0 {
             LengthOrAuto::Auto => ULength::<Vertical>::parse_str("100%").unwrap(),
             LengthOrAuto::Length(l) => l,
-        });
+        };
 
         IntrinsicDimensions {
             width: w,
@@ -144,42 +152,49 @@ impl Svg {
         }
     }
 
-    fn get_unnormalized_offset(&self) -> (Length<Horizontal>, Length<Vertical>) {
+    fn get_unnormalized_offset(
+        &self,
+        values: &ComputedValues,
+    ) -> (Length<Horizontal>, Length<Vertical>) {
         // these defaults are per the spec
-        let x = self
-            .x
-            .unwrap_or_else(|| Length::<Horizontal>::parse_str("0").unwrap());
-        let y = self
-            .y
-            .unwrap_or_else(|| Length::<Vertical>::parse_str("0").unwrap());
+        let x = values.x().0;
+        let y = values.y().0;
 
         (x, y)
     }
 
-    fn get_unnormalized_size(&self) -> (ULength<Horizontal>, ULength<Vertical>) {
+    fn get_unnormalized_size(
+        &self,
+        values: &ComputedValues,
+    ) -> (ULength<Horizontal>, ULength<Vertical>) {
         // these defaults are per the spec
-        let w = match self.width {
-            None | Some(LengthOrAuto::Auto) => ULength::<Horizontal>::parse_str("100%").unwrap(),
-            Some(LengthOrAuto::Length(l)) => l,
+        let w = match values.width().0 {
+            LengthOrAuto::Auto => ULength::<Horizontal>::parse_str("100%").unwrap(),
+            LengthOrAuto::Length(l) => l,
         };
-        let h = match self.height {
-            None | Some(LengthOrAuto::Auto) => ULength::<Vertical>::parse_str("100%").unwrap(),
-            Some(LengthOrAuto::Length(l)) => l,
+        let h = match values.height().0 {
+            LengthOrAuto::Auto => ULength::<Vertical>::parse_str("100%").unwrap(),
+            LengthOrAuto::Length(l) => l,
         };
         (w, h)
     }
 
-    fn get_viewport(&self, params: &NormalizeParams, outermost: bool) -> Rect {
+    fn get_viewport(
+        &self,
+        params: &NormalizeParams,
+        values: &ComputedValues,
+        outermost: bool,
+    ) -> Rect {
         // x & y attributes have no effect on outermost svg
         // http://www.w3.org/TR/SVG/struct.html#SVGElement
         let (nx, ny) = if outermost {
             (0.0, 0.0)
         } else {
-            let (x, y) = self.get_unnormalized_offset();
+            let (x, y) = self.get_unnormalized_offset(values);
             (x.to_user(params), y.to_user(params))
         };
 
-        let (w, h) = self.get_unnormalized_size();
+        let (w, h) = self.get_unnormalized_size(values);
         let (nw, nh) = (w.to_user(params), h.to_user(params));
 
         Rect::new(nx, ny, nx + nw, ny + nh)
@@ -204,7 +219,7 @@ impl Svg {
             None
         };
 
-        let svg_viewport = self.get_viewport(&params, !has_parent);
+        let svg_viewport = self.get_viewport(&params, values, !has_parent);
 
         let is_measuring_toplevel_svg = !has_parent && draw_ctx.is_measuring();
 
@@ -243,10 +258,6 @@ impl SetAttributes for Svg {
                 expanded_name!("", "preserveAspectRatio") => {
                     self.preserve_aspect_ratio = attr.parse(value)?
                 }
-                expanded_name!("", "x") => self.x = attr.parse(value)?,
-                expanded_name!("", "y") => self.y = attr.parse(value)?,
-                expanded_name!("", "width") => self.width = attr.parse(value)?,
-                expanded_name!("", "height") => self.height = attr.parse(value)?,
                 expanded_name!("", "viewBox") => self.vbox = attr.parse(value)?,
                 _ => (),
             }
@@ -548,7 +559,7 @@ impl Draw for Link {
             }
         }
 
-        let cascaded = CascadedValues::new(cascaded, node);
+        let cascaded = CascadedValues::clone_with_node(cascaded, node);
         let values = cascaded.get();
 
         let elt = node.borrow_element();
