@@ -1,6 +1,7 @@
 //! The main XML parser.
 
-use encoding_rs::Encoding;
+use encoding::label::encoding_from_whatwg_label;
+use encoding::DecoderTrap;
 use gio::{
     prelude::BufferedInputStreamExt, BufferedInputStream, Cancellable, ConverterInputStream,
     InputStream, ZlibCompressorFormat, ZlibDecompressor,
@@ -116,7 +117,7 @@ pub struct XmlState {
 
 /// Errors returned from XmlState::acquire()
 ///
-/// These follow the terminology from https://www.w3.org/TR/xinclude/#terminology
+/// These follow the terminology from <https://www.w3.org/TR/xinclude/#terminology>
 enum AcquireError {
     /// Resource could not be acquired (file not found), or I/O error.
     /// In this case, the `xi:fallback` can be used if present.
@@ -523,7 +524,7 @@ impl XmlState {
 
         let encoding = encoding.unwrap_or("utf-8");
 
-        let encoder = Encoding::for_label_no_replacement(encoding.as_bytes()).ok_or_else(|| {
+        let encoder = encoding_from_whatwg_label(encoding).ok_or_else(|| {
             AcquireError::FatalError(format!(
                 "unknown encoding \"{}\" for \"{}\"",
                 encoding, aurl
@@ -531,9 +532,12 @@ impl XmlState {
         })?;
 
         let utf8_data = encoder
-            .decode_without_bom_handling_and_without_replacement(&binary.data)
-            .ok_or_else(|| {
-                AcquireError::FatalError(format!("could not convert contents of \"{aurl}\" from character encoding \"{encoding}\""))
+            .decode(&binary.data, DecoderTrap::Strict)
+            .map_err(|e| {
+                AcquireError::FatalError(format!(
+                    "could not convert contents of \"{}\" from character encoding \"{}\": {}",
+                    aurl, encoding, e
+                ))
             })?;
 
         self.element_creation_characters(&utf8_data);
