@@ -1,3 +1,4 @@
+use float_cmp::approx_eq;
 use gio::MemoryInputStream;
 use glib::Bytes;
 use predicates::prelude::*;
@@ -114,7 +115,7 @@ impl DetailPredicate<SvgPredicate> {
             Detail::Size(d) => {
                 let renderer = CairoRenderer::new(handle);
                 let dimensions = renderer.intrinsic_dimensions();
-                (dimensions.width, dimensions.height) == (Some(d.w), Some(d.h))
+                (dimensions.width, dimensions.height) == (d.w, d.h)
             }
         }
     }
